SimnodeApiClient

Trait SimnodeApiClient 

pub trait SimnodeApiClient: ClientT {
    // Provided methods
    fn author_extrinsic<'life0, 'async_trait>(
        &'life0 self,
        call: Bytes,
        account: String,
    ) -> Pin<Box<dyn Future<Output = Result<Bytes, Error>> + Send + 'async_trait>>
       where Self: Sync + 'async_trait,
             'life0: 'async_trait { ... }
    fn revert_blocks<'life0, 'async_trait>(
        &'life0 self,
        n: u32,
    ) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>
       where Self: Sync + 'async_trait,
             'life0: 'async_trait { ... }
    fn upgrade_signal<'life0, 'async_trait>(
        &'life0 self,
        go_ahead: bool,
    ) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>
       where Self: Sync + 'async_trait,
             'life0: 'async_trait { ... }
}
Client implementation for the SimnodeApi RPC API.

Provided Methods

fn author_extrinsic<'life0, 'async_trait>( &'life0 self, call: Bytes, account: String, ) -> Pin<Box<dyn Future<Output = Result<Bytes, Error>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

Constructs an extrinsic with an empty signature and the given AccountId as the Signer using simnode’s runtime api.

fn revert_blocks<'life0, 'async_trait>( &'life0 self, n: u32, ) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

reverts n number of blocks and their state from the chain.

fn upgrade_signal<'life0, 'async_trait>( &'life0 self, go_ahead: bool, ) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

Insert the [UpgradeGoAhead] command into the inherents as if it came from the relay chain. This greenlights/aborts a pending runtime upgrade.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<TypeJsonRpseeInteral> SimnodeApiClient for TypeJsonRpseeInteral
where TypeJsonRpseeInteral: ClientT,